
version 16
clear all
capture cd "$GoogleDriveWork"
capture cd "$GoogleDriveLaptop"
capture cd "$LinuxDriveWork"
capture cd "$Presentations"
cd ".\Talks\AllTalks\29_SurveySampling_Intro\examples\"



global Width16x9 = 1920*2
global Height16x9 = 1080*2
global Width4x3 = 1440*2
global Height4x3 = 1080*2

use SurveyIntro.dta, clear
describe id psu strata wt_mec wt_interview

// Original NHANES svyset
// See https://www.cdc.gov/nchs/tutorials/nhanes/stata_tips.htm
svyset psu, strata(strata) weight(wt_mec) vce(linearized) singleunit(missing)

describe id female race age education income married weight height bmi bmi_cat healthstat
describe sbp dbp chol hdl glucose insulin HbA1c diabetes protein carbs sugars fiber fat calories
describe alcohol smoke smokenum smokeage marijuana cocaine heroin methamphetamine

// Chuck's fake svyset
// This is for demonstration purposes only
/*
svyset county,    strata(county_str)       fpc(county_fpc)    weight(county_wt)    ///
       vce(linearized) singleunit(missing)                                         ///
    || census,    strata(census_str)       fpc(census_fpc)    weight(census_wt)    ///
    || household, strata(household_str)    fpc(household_fpc) weight(household_wt) ///
    || person,    strata(person_str)       fpc(person_fpc)    weight(person_wt)
*/

svy: mean age    
svy: mean age, over(female) cformat(%9.2f)

svy: mean age, over(race) cformat(%9.2f)
svy: mean age, over(race female) cformat(%9.2f)

// Use the "subpop()" option to restrict analyses.  DO NOT use "if".
generate WhiteFemale = (race==2 & female==1)
svy, subpop(WhiteFemale): mean age


svy: tabulate diabetes, format(%9.3f)
svy: tabulate diabetes healthstat, format(%9.3f) pearson lr

svy: regress sbp c.age##i.female
margins female, at(age=(20(10)80)) vce(unconditional)
marginsplot
graph export ./graphs/LinearRegression.png, as(png)          ///
             width($Width16x9) height($Height16x9) replace

svy: logistic diabetes c.age##i.female
margins female, at(age=(20(10)80)) vce(unconditional)
marginsplot
graph export ./graphs/LogisticRegression.png, as(png)          ///
             width($Width16x9) height($Height16x9) replace

svy: ologit healthstat c.age##i.female
margins, at(age=(20(10)80))  vce(unconditional)
marginsplot
graph export ./graphs/OrdinalRegression.png, as(png)          ///
             width($Width16x9) height($Height16x9) replace

             
svy: gsem (Depression -> depressQ1@1 depressQ2 depressQ3 depressQ4 depressQ5 ///
                         depressQ6 depressQ7 depressQ8 depressQ9 depressQ10  ///
                         healthstat                                          ///
                         , family(ordinal) link(logit))                      ///
                         , latent(Depression) means(Depression@0)

predict pr_healthstat*, pr
predict depression, latent(Depression)

twoway (line pr_healthstat41 depression, sort lcolor(blue) lwidth(thick)) 	 ///
	   (line pr_healthstat42 depression, sort lcolor(midblue) lwidth(thick)) ///
	   (line pr_healthstat43 depression, sort lcolor(purple) lwidth(thick))  ///
	   (line pr_healthstat44 depression, sort lcolor(orange) lwidth(thick))  ///
	   (line pr_healthstat45 depression, sort lcolor(red) lwidth(thick))	 ///
	   , ytitle(Predicted Probability of Health Category, 					 ///
	            size(small) margin(medsmall)) 								 ///
	   ylabel(0(0.1)0.7, angle(horizontal)) 								 ///
	   xlabel(-3(1)8) 													     ///
	   title("Predicted Probability of Health Status Category"               ///
              , size(large) color(black))                                    ///
	   subtitle("by Predicted Depression Score", size(large) color(black)) 	 ///
	   legend(order(1 "Excellent" 2 "Very Good" 3 "Good" 4 "Fair" 5 "Poor")  ///
	          rows(1) size(small) position(12) ring(0))

graph export ./graphs/Depression_HealthStatus.png, as(png)          ///
             width($Width16x9) height($Height16x9) replace

drop depression pr_healthstat*





    
    

