
version 16
clear all
capture cd "$GoogleDriveWork"
capture cd "$GoogleDriveLaptop"
capture cd "$LinuxDriveWork"
capture cd "$Presentations"
capture cd "$GoogleDriveNYU"
cd ".\Talks\AllTalks\29_SurveySampling_Intro\examples\nhanes_raw\"



global Width16x9 = 1920*2
global Height16x9 = 1080*2
global Width4x3 = 1440*2
global Height4x3 = 1080*2





/*
NHANES Data Source:
===================
https://wwwn.cdc.gov/nchs/nhanes/continuousnhanes/default.aspx?BeginYear=2015

Data Files
==========
BMX_I.XPT    = "Body Measures"
BPX_I.XPT    = "Blood Pressure"
DR1TOT_I.XPT = "Dietary Interview - Total Nutrient Intakes, First Day"
DR2TOT_I.XPT = "Dietary Interview - Total Nutrient Intakes, Second Day"
DEMO_I.XPT   = "Demographic Variables and Sample Weights"
GHB_I.XPT    = "Glycohemoglobin"
GLU_I.XPT    = "Plasma Fasting Glucose"
HDL_I.XPT    = "Cholesterol - High-Density Lipoprotein (HDL)"
INS_I.XPT    = "Insulin"
OGTT_I.XPT   = "Oral Glucose Tolerance Test"
TCHOL_I.XPT  = "Cholesterol - Total"
*/



// Import, save, and svyset example
// ===============================================================
import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/BMX_I.XPT", clear
sort seqn
save BMX_I.dta, replace

import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DEMO_I.XPT", clear
sort seqn
save DEMO_I.dta, replace

merge 1:1 seqn using BMX_I

svyset sdmvpsu, strata(sdmvstra) weight(wtint2yr) vce(linearized) singleunit(missing)

describe seqn sddsrvyr riagendr ridageyr wtint2yr wtmec2yr sdmvpsu sdmvstra








// Import the SAS Transport files from the CDC website, 
// 	  sort them on the ID variable (seqn),
//	  and save them to Stata datasets
// =============================================================================
local FileList "BMX_I BPX_I DR1TOT_I DR2TOT_I DEMO_I GHB_I GLU_I HDL_I INS_I OGTT_I TCHOL_I CBQ_I DUQ_I DPQ_I SMQ_I ALQ_I DIQ_I HSQ_I"  			
foreach file of local FileList {
	clear
	import sasxport5 "https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/`file'.XPT"
	sort seqn
	save `file', replace
}



// Create Lab file
// =============================
use TCHOL_I, clear
merge 1:1 seqn using "HDL_I.dta"
drop _merge
merge 1:1 seqn using "GLU_I.dta"
drop _merge
merge 1:1 seqn using "GHB_I.dta"
drop _merge
merge 1:1 seqn using "INS_I.dta"
drop _merge

rename lbxtc chol
rename lbdhdd hdl
rename lbxglu glucose
rename lbxgh HbA1c
rename lbxin insulin
keep seqn chol hdl glucose HbA1c insulin
order seqn chol hdl glucose insulin HbA1c
rename seqn id
sort id
save lab, replace


// Create the Diabetes dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DIQ_I.htm
// =====================================================
use DIQ_I.dta, clear
rename seqn id
rename diq010 diabetes
mvdecode diabetes, mv(7=.a \ 9=.b)
recode diabetes (1 = 1) (2/3 = 0)
label define diabetes 0 "No"            /// 	
                      1 "Yes"           ///	
  					 .a "Refused"	    ///
					 .b "Don't Know" 
label values diabetes diabetes
keep id diabetes
sort id
save diabetes, replace


// Create the Health Status dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/HSQ_I.htm#HSD010
// ===========================================================
use HSQ_I.dta, clear
rename seqn id
rename hsd010 healthstat
mvdecode healthstat, mv(7=.a \ 9=.b)
label define hstat 1 "Excellent"     /// 	
                   2 "Very good"     ///
                   3 "Good"          ///  
                   4 "Fair"          ///
                   5 "Poor"          ///
  				  .a "Refused"	     ///
				  .b "Don't Know" 
label values healthstat hstat
keep id healthstat
sort id
save healthstatus, replace



// Create the BloodPressure dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/BPX_I.htm
// ====================================================
copy BPX_I.dta bloodpressure.dta, replace
use bloodpressure, clear
egen sbp = rowmean(bpxsy1 bpxsy2 bpxsy3 bpxsy4)
replace sbp = floor(sbp)
egen dbp = rowmean(bpxdi1 bpxdi2 bpxdi3 bpxdi4)
replace dbp = floor(dbp)
rename seqn id
keep id sbp dbp
sort id
save bloodpressure, replace


// Create the Anthro dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/BMX_I.htm
// =====================================================
copy BMX_I.dta anthro.dta, replace
use anthro, clear
rename bmxwt weight
rename bmxht height
rename bmxbmi bmi
rename bmdbmic bmi_cat
rename seqn id
sort id
keep id weight height bmi bmi_cat
order id weight height bmi bmi_cat
save anthro, replace

// Create Diet dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DR2TOT_I.htm
// ========================================================
copy DR2TOT_I.dta diet.dta, replace
use diet.dta
rename dr2tkcal calories
rename dr2tprot protein
rename dr2tcarb carbs
rename dr2tsugr sugars
rename dr2tfibe fiber
rename dr2ttfat fat
keep calories seqn protein carbs sugars fiber fat
order seqn seqn protein carbs sugars fiber fat
rename seqn id  
sort id
save diet.dta, replace

// Create Demographic dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DEMO_I.htm
// =====================================================
use DEMO_I.dta, clear
rename seqn id
rename riagendr gender
rename ridageyr age
rename ridreth1 race
rename dmdeduc2 education
rename indhhin2 income
rename dmdmartl married
rename wtint2yr wt_interview
rename wtmec2yr wt_mec
rename sdmvpsu psu
rename sdmvstra strata  
sort id
keep id gender age race education income married wt_interview wt_mec psu strata
order id gender age race education income married  wt_interview wt_mec psu strata
save demo.dta, replace

// Create Depression dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DPQ_I.htm
// =====================================================
use DPQ_I, clear
rename seqn id  
rename dpq010 depressQ1
rename dpq020 depressQ2
rename dpq030 depressQ3
rename dpq040 depressQ4
rename dpq050 depressQ5
rename dpq060 depressQ6
rename dpq070 depressQ7
rename dpq080 depressQ8
rename dpq090 depressQ9
rename dpq100 depressQ10
mvdecode depress*, mv(7=.a \ 9=.b)
label define depress 0 "Not at all"               /// 	
                     1 "Several days"             ///	
                     2 "More than half the days"  /// 	
                     3 "Nearly every day"         /// 	
					.a "Refused"	                 ///
					.b "Don't Know" 
label values depress* depress
sort id
save depression, replace


// Create Alcohol dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/ALQ_I.htm
// ====================================================
use ALQ_I, clear
rename seqn id  
rename alq130 alcohol
mvdecode alcohol, mv(777=.a \ 999=.b)
label define alcohol  0 "None"                 /// 	
                     15 "15 drinks or more"    ///	
					 .a "Refused"	           ///
					 .b "Don't Know" 
label values alcohol alcohol
keep id alcohol
sort id
save alcohol, replace


// Create Smoking dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/SMQ_I.htm
// ====================================================
use SMQ_I, clear
rename seqn id  
rename smd030 smokeage 
rename smq040 smoke 
rename smd650 smokenum
keep id smoke smokenum smokeage
order id smoke smokenum smokeage
mvdecode smokeage, mv(777=.a \ 999=.b)
label define smokeage 0 "Never smoked regularly"   /// 	
					  .a "Refused"	               ///
					  .b "Don't Know" 
label values smokeage smokeage
mvdecode smoke, mv(7 9)
recode smoke (1/2 = 1) (3 = 0)
label define smoke 0 "Nonsmoker" 1 "Smoker"
label values smoke smoke
mvdecode smokenum, mv(777=.a \ 999=.b)
label define smokenum .a "Refused" .b "Don't know"
label values smokenum smokenum
save smoke, replace


// Create Drugs dataset
// https://wwwn.cdc.gov/Nchs/Nhanes/2015-2016/DUQ_I.htm
// ====================================================
use DUQ_I, clear
rename seqn id  
rename duq200 marijuana
rename duq250 cocaine
rename duq290 heroin
rename duq330 methamphetamine
keep id marijuana cocaine heroin methamphetamine
mvdecode marijuana, mv(7=.a \ 9=.b)
replace marijuana = abs(marijuana-2)
label define YesNo 0 "No" 1 "Yes" .a "Refused" .b "Don't know"
label values marijuana YesNo
mvdecode cocaine, mv(7=.a \ 9=.b)
replace cocaine = abs(cocaine-2)
label values cocaine YesNo
mvdecode heroin, mv(7=.a \ 9=.b)
replace heroin = abs(heroin-2)
label values heroin YesNo
mvdecode methamphetamine, mv(7=.a \ 9=.b)
replace methamphetamine = abs(methamphetamine-2)
label values methamphetamine YesNo
save drugs, replace

// Create sampling variables loosely based on the NHANES sampline scheme
// https://www.cdc.gov/nchs/data/series/sr_02/sr02_162.pdf
// ======================================================================
clear
set obs 15
gen county = _n
gen county_str = rbinomial(1,0.5)
label define county_str 0 "Small" 1 "Large"
label values county_str county_str
generate county_fpc = .
forvalues strata = 0/1 {
    local fpc = runiform(0.95,0.99)
    replace  county_fpc = `fpc' if county_str == `strata'
}
gen county_wt = 1
label var county "Sample Stage 1: County PSU"
label var county_str "Sample Stage 1: County Strata"
label var county_fpc "Sample Stage 1: County FPC"
label var county_wt "Sample Stage 1: County Sample Weight"

expand 25
gen census = _n
gen census_str = rbinomial(1,0.5)
label define census_str 0 "Rural" 1 "Urban"
label values census_str census_str
gen census_fpc = 1
gen census_wt = 1
label var census "Sample Stage 2: Census PSU"
label var census_str "Sample Stage 2: Census Strata"
label var census_fpc "Sample Stage 2: Census FPC"
label var census_wt "Sample Stage 2: Census Sample Weight"

expand 6
gen household = _n
gen household_str = rbinomial(1,0.5)
label define household_str 0 "Single" 1 "Multi"
label values household_str household_str
gen household_fpc = 1
gen household_wt = 1 
label var household "Sample Stage 3: Household PSU"
label var household_str "Sample Stage 3: Household Strata"
label var household_fpc "Sample Stage 3: Household FPC"
label var household_wt "Sample Stage 3: Household Sample Weight"

expand 5
gen person = _n
gen person_str = rbinomial(1,0.5)
label define person_str 0 "Male" 1 "Female"
label values person_str person_str
gen person_fpc = 1
gen person_wt = 1
label var person "Sample Stage 4: Person PSU"
label var person_str "Sample Stage 4: Person Strata"
label var person_fpc "Sample Stage 4: Person FPC"
label var person_wt "Sample Stage 4: Person Sample Weight"

gen RandNum = runiform()
sort RandNum
gen id = _n
drop RandNum
sort id
save weights, replace


// Merge all the files into a single dataset
// =========================================== 
use demo, clear
merge 1:1 id using "anthro.dta"
drop _merge
merge 1:1 id using "healthstatus.dta"
drop _merge
merge 1:1 id using "bloodpressure.dta"
drop _merge
merge 1:1 id using "lab.dta"
drop _merge
merge 1:1 id using "diabetes.dta"
drop _merge
merge 1:1 id using "diet.dta"
drop _merge
merge 1:1 id using "alcohol.dta"
drop _merge
merge 1:1 id using "smoke.dta"
drop _merge
merge 1:1 id using "drugs.dta"
drop _merge
merge 1:1 id using "depression.dta"
drop _merge
replace id = _n
sort id
merge 1:1 id using "weights.dta"
keep if _merge==3
drop _merge


// Label the variables
// =============================================================================
label var id         "Participant Identification Number"
label var gender     "Female"
label var age        "Age (years)"
label var race       "Race"
label var education  "Education level - Adults 20+"
label var income     "Annual household income"
label var married    "Marital status"

label var weight     "Weight (kg)"
label var height     "Standing Height (cm)"
label var bmi        "Body Mass Index (kg/m**2)"
label var bmi_cat    "BMI Category - Children/Youth"

label var sbp        "Systolic Blood Pressure (mmHg)"
label var dbp        "Diastolic Blood Pressure (mmHg)"

label var protein    "Protein (gm)"
label var carbs      "Carbohydrate (gm)"
label var sugars     "Total sugars (gm)"
label var fiber      "Dietary fiber (gm)"
label var fat        "Total fat (gm)"
label var calories   "Energy (kcal)"

label var chol       "Total Cholesterol (mg/dL)"
label var hdl        "Direct HDL-Cholesterol (mg/dL)"
label var glucose    "Fasting Glucose (mg/dL)"
label var insulin    "Insulin (uU/mL)"
label var HbA1c      "Glycohemoglobin (%)"




// Convert string variables to numeric variables
// =============================================================================
destring education, replace
destring married, replace  
destring height, replace    
destring bmi, replace       
destring bmi_cat, replace   
destring protein, replace   
destring carbs, replace     
destring sugars, replace    
destring fiber, replace     
destring fat, replace       
destring calories, replace  
destring chol, replace      
destring hdl, replace       
destring glucose, replace 
destring insulin, replace   
destring HbA1c, replace     

replace gender = gender-1
rename gender female
label define female 0 "Male" 1 "Female"
label values female female

label define race 1 	"Mexican American" 	///
                  2 	"Other Hispanic"    /// 	
                  3 	"White" 	        /// 	
                  4 	"Black" 	        /// 	
                  5 	"Other"
label values race race

recode race (1/2 = 1 "Hispanic")	///
		    (  3 = 2 "White")		///
			(  4 = 3 "Black")		///
			(  5 = 4 "Other")		///
			, gen(race2)
tab race race2
drop race
rename race2 race
label var race "Race"
order race, after(female)

mvdecode education, mv(7=.a \ 9=.b)
label define educ 1 "<9th grade"   /// 	
                  2 "9-11 grade"   ///	
                  3 "HS grad/GED"  /// 	
                  4 "Some college" /// 	
                  5 "College grad" ///
				 .a "Refused"	    ///
				 .b "Don't Know" 
label values education educ

mvdecode married, mv(77=.a \ 99=.b)
label define married 1 "Married"         /// 	
                     2 "Widowed"         ///	
                     3 "Divorced"        /// 	
                     4 "Separated"       /// 	
                     5 "Never Married"   ///
					 6 "Live w/ Partner" ///
					.a "Refused"	     ///
					.b "Don't Know" 
label values married married



label data "Example dataset based on NHANES.  For pedagogical use only. (see notes)"
notes _dta: "This dataset was created on September 10, 2019 by Chuck Huber of StataCorp LLC"
notes _dta: "This dataset is based on the NHANES 2015-2016"
notes _dta: "Reference: https://wwwn.cdc.gov/nchs/nhanes/continuousnhanes/default.aspx?BeginYear=2015"
notes _dta: "The sample weights are completely fictitious"
notes _dta: "These data are for pedogogical purposes only."
notes _dta: "DO NOT believe ANY results based on this dataset"




order wt_interview wt_mec psu strata, last
replace county_wt = wt_interview
sort id
compress
save ./../SurveyIntro.dta, replace

local deletelist "lab bloodpressure anthro diet alcohol smoke drugs demo depression diabetes healthstatus"

foreach deletefile of local deletelist {
    rm "`deletefile'.dta"
}

